package apps;

import java.io.IOException;
import java.util.List;

import com.ibm.rhapsody.apps.utils.IOServices;
import com.ibm.rhapsody.apps.utils.Reporter;
import com.telelogic.rhapsody.core.IRPApplication;
import com.telelogic.rhapsody.core.IRPModelElement;

public class MBDGVisitor {
	private MBDGConfiguration configuration;
	private MBDGTemplateGenerator templateGenerator;
	private MBDGDocumentGenerator documentGenerator;
	private MBDGHTTPWebServerLauncher htppWebServerLauncher;
	private boolean withDescendants;

	public MBDGVisitor(IRPApplication rhapsody, MBDGConfiguration configuration, boolean withDescendants) throws IOException {
		this.setWithDescendants(withDescendants);
		setConfiguration(configuration);

		templateGenerator = new MBDGTemplateGenerator(rhapsody, configuration);
		documentGenerator = new MBDGDocumentGenerator(configuration);
		htppWebServerLauncher = new MBDGHTTPWebServerLauncher(rhapsody);
	}

	public void visit(IRPModelElement root) throws IOException {
		try {
			String label = root.getDisplayName();
			Reporter.report(String.format("Generating Document: %s ...\nTemplate Path: %s", label, configuration.getGeneratedTemplatePath()));

			// Reference to a new terms in schema using new term name and not its applicable metaclass 
			MBDGUtils.enableNewTermSupportInFullForMBDG(true);

			templateGenerator.cleanWorkarea();

			// Unzip all RPE template according to document elements contained in MBDG profile 
			templateGenerator.unzipTemplates(root);
			// Export an active Rhapsody instance schema
			templateGenerator.exportSchema();
			// Launch HTTP server in order to allow RPE extract information form Rhapsody. 
			htppWebServerLauncher.start();

			copyAdditionalFiles();

			// Build simple document model according to a model report 
			MBDGSimpleModel simpleModel = buildSimpleModel(root);		

			// According to root create main template
			StringBuilder generatedTemplate = visit(simpleModel.getRoot(), 0);

			// Create main template (.dta) which represents model based document. 
			// This template can be launched from RPE
			templateGenerator.createTemplate(simpleModel.getRoot());
			templateGenerator.updatePortInFiles(htppWebServerLauncher.getPort());
			templateGenerator.updateSchema();		
			templateGenerator.zipTemplate(generatedTemplate);

			documentGenerator.generateAndOpen();

		} finally {
			onFinish();
		}
	}

	private void onFinish() {
		MBDGTemplateHandlesIdsUpdater.reset();
	}

	private MBDGSimpleModel buildSimpleModel(IRPModelElement root) throws IOException {
		MBDGSimpleModel simpleModel = new MBDGSimpleModel();
		MBDGSimpleModelBuilder builder = new MBDGSimpleModelBuilder(simpleModel);
		builder.setWithDescendants(isWithDescendants());
		builder.build(root);

		MBDGTemplateProvider templateProvider = new MBDGTemplateProvider(simpleModel, configuration);
		templateProvider.assignTemplates();

		simpleModel.report();

		return simpleModel;
	}

	protected void copyAdditionalFiles() throws IOException {
		IOServices.copyDirRecursive(configuration.getDocumentSpecificationsDirectory(), configuration.getWorkareaDirectory(), true);
	}

	protected StringBuilder visit(MBDGElement element, int level) throws IOException {
		if (MBDGUtils.isType(element, "DocDocument")) {
			level = 0;
		}
		StringBuilder template = expandTemplate(element, level);

		MBDGMapExpander mapExpander = new MBDGMapExpander(template);
		List<MBDGElement> descendants = element.getDescendants();
		for (MBDGElement descendant : descendants) {
			String keyword = MBDGUtils.getKeywordTagValue(descendant.getElement());
			if (keyword != null && mapExpander.containsKey(keyword)) {
				StringBuilder childTemplate = visit(descendant, level+1);
				mapExpander.addTemplatePattern(keyword, childTemplate);
			}
		}
		mapExpander.expand();
		mapExpander.removeTemplateComments();
		return template;
	}

	private StringBuilder expandTemplate(MBDGElement element, int level) throws IOException {
		StringBuilder template = new StringBuilder(element.getTemplate());		
		MBDGExpander expander = new MBDGExpander(template);
		expander.expand(element, level);
		return template;
	}	

	public MBDGConfiguration getConfiguration() {
		return configuration;
	}

	public void setConfiguration(MBDGConfiguration configuration) {
		this.configuration = configuration;
	}

	public boolean isWithDescendants() {
		return withDescendants;
	}

	public void setWithDescendants(boolean withDescendants) {
		this.withDescendants = withDescendants;
	}	
}
